==> jc-1.4.0.tar.gz: gnu/xml/dom/DomNode__24DomEventException.h <==
// final class gnu.xml.dom.DomNode$DomEventException

// class file dependencies
// @dep_class 49c19b26c4169d1b gnu_xml_dom_DomNode__24DomEventException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 25bca8504e3fdf15 org_w3c_dom_events_EventException

// header file dependencies
// @dep_header org_w3c_dom_events_EventException

#include "org/w3c/dom/events/EventException.h"

#ifndef _JC_gnu_xml_dom_DomNode__24DomEventException_H_
#define _JC_gnu_xml_dom_DomNode__24DomEventException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomNode__24DomEventException$sub_refs	_jc_gnu_xml_dom_DomNode__24DomEventException$sub_refs;
typedef struct _jc_gnu_xml_dom_DomNode__24DomEventException$sub_nonrefs	_jc_gnu_xml_dom_DomNode__24DomEventException$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomNode__24DomEventException$refs	_jc_gnu_xml_dom_DomNode__24DomEventException$refs;
typedef struct _jc_gnu_xml_dom_DomNode__24DomEventException$nonrefs	_jc_gnu_xml_dom_DomNode__24DomEventException$nonrefs;
typedef struct _jc_gnu_xml_dom_DomNode__24DomEventException$object	_jc_gnu_xml_dom_DomNode__24DomEventException$object;

typedef const struct _jc_gnu_xml_dom_DomNode__24DomEventException$vmethods	_jc_gnu_xml_dom_DomNode__24DomEventException$vmethods;
typedef const struct _jc_gnu_xml_dom_DomNode__24DomEventException$vtable	_jc_gnu_xml_dom_DomNode__24DomEventException$vtable;
typedef const struct _jc_gnu_xml_dom_DomNode__24DomEventException$vtype	_jc_gnu_xml_dom_DomNode__24DomEventException$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomNode__24DomEventException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24DomEventException$object *);

// Virtual methods structure
struct _jc_gnu_xml_dom_DomNode__24DomEventException$vmethods {
};

// Vtable
struct _jc_gnu_xml_dom_DomNode__24DomEventException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_org_w3c_dom_events_EventException$vmethods	org_w3c_dom_events_EventException;
	_jc_gnu_xml_dom_DomNode__24DomEventException$vmethods	gnu_xml_dom_DomNode__24DomEventException;
};

// Vtype
struct _jc_gnu_xml_dom_DomNode__24DomEventException$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomNode__24DomEventException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomNode__24DomEventException$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomNode__24DomEventException$refs {
    _jc_gnu_xml_dom_DomNode__24DomEventException$sub_refs	gnu_xml_dom_DomNode__24DomEventException;
    _jc_org_w3c_dom_events_EventException$sub_refs	org_w3c_dom_events_EventException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomNode__24DomEventException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomNode__24DomEventException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_org_w3c_dom_events_EventException$sub_nonrefs	org_w3c_dom_events_EventException;
    _jc_gnu_xml_dom_DomNode__24DomEventException$sub_nonrefs	gnu_xml_dom_DomNode__24DomEventException;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomNode__24DomEventException$object {
	_jc_gnu_xml_dom_DomNode__24DomEventException$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomNode__24DomEventException$vtype	*vtype;
	_jc_gnu_xml_dom_DomNode__24DomEventException$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomNode__24DomEventException$vtype _jc_gnu_xml_dom_DomNode__24DomEventException$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomNode__24DomEventException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomNode__24DomEventException$class_object;

#endif	/* _JC_gnu_xml_dom_DomNode__24DomEventException_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/dom/DomNode__24DomEventException.h <==
// final class gnu.xml.dom.DomNode$DomEventException

// class file dependencies
// @dep_class 49c19b26c4169d1b gnu_xml_dom_DomNode__24DomEventException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 25bca8504e3fdf15 org_w3c_dom_events_EventException

// header file dependencies
// @dep_header org_w3c_dom_events_EventException

#include "org/w3c/dom/events/EventException.h"

#ifndef _JC_gnu_xml_dom_DomNode__24DomEventException_H_
#define _JC_gnu_xml_dom_DomNode__24DomEventException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomNode__24DomEventException$sub_refs	_jc_gnu_xml_dom_DomNode__24DomEventException$sub_refs;
typedef struct _jc_gnu_xml_dom_DomNode__24DomEventException$sub_nonrefs	_jc_gnu_xml_dom_DomNode__24DomEventException$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomNode__24DomEventException$refs	_jc_gnu_xml_dom_DomNode__24DomEventException$refs;
typedef struct _jc_gnu_xml_dom_DomNode__24DomEventException$nonrefs	_jc_gnu_xml_dom_DomNode__24DomEventException$nonrefs;
typedef struct _jc_gnu_xml_dom_DomNode__24DomEventException$object	_jc_gnu_xml_dom_DomNode__24DomEventException$object;

typedef const struct _jc_gnu_xml_dom_DomNode__24DomEventException$vmethods	_jc_gnu_xml_dom_DomNode__24DomEventException$vmethods;
typedef const struct _jc_gnu_xml_dom_DomNode__24DomEventException$vtable	_jc_gnu_xml_dom_DomNode__24DomEventException$vtable;
typedef const struct _jc_gnu_xml_dom_DomNode__24DomEventException$vtype	_jc_gnu_xml_dom_DomNode__24DomEventException$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomNode__24DomEventException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24DomEventException$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomNode__24DomEventException$vmethods {
};

// Vtable
struct _jc_gnu_xml_dom_DomNode__24DomEventException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_org_w3c_dom_events_EventException$vmethods	org_w3c_dom_events_EventException;
	_jc_gnu_xml_dom_DomNode__24DomEventException$vmethods	gnu_xml_dom_DomNode__24DomEventException;
};

// Vtype
struct _jc_gnu_xml_dom_DomNode__24DomEventException$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomNode__24DomEventException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomNode__24DomEventException$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomNode__24DomEventException$refs {
    _jc_gnu_xml_dom_DomNode__24DomEventException$sub_refs	gnu_xml_dom_DomNode__24DomEventException;
    _jc_org_w3c_dom_events_EventException$sub_refs	org_w3c_dom_events_EventException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomNode__24DomEventException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomNode__24DomEventException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_org_w3c_dom_events_EventException$sub_nonrefs	org_w3c_dom_events_EventException;
    _jc_gnu_xml_dom_DomNode__24DomEventException$sub_nonrefs	gnu_xml_dom_DomNode__24DomEventException;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomNode__24DomEventException$object {
	_jc_gnu_xml_dom_DomNode__24DomEventException$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomNode__24DomEventException$vtype	*vtype;
	_jc_gnu_xml_dom_DomNode__24DomEventException$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomNode__24DomEventException$vtype _jc_gnu_xml_dom_DomNode__24DomEventException$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomNode__24DomEventException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomNode__24DomEventException$class_object;

#endif	/* _JC_gnu_xml_dom_DomNode__24DomEventException_H_ */
